Title: [161018] trunk/Source/WebKit2
Revision
161018
Author
zandober...@gmail.com
Date
2013-12-23 14:05:22 -0800 (Mon, 23 Dec 2013)

Log Message

Unreviewed build fix for GTK and EFL after r161007.

* UIProcess/DrawingAreaProxyImpl.cpp:
(WebKit::DrawingAreaProxyImpl::waitForAndDispatchDidUpdateBackingStoreState):
Use std::chrono::milliseconds instead of double for the timeout parameter to
CoreIPC::Connection::waitForAndDispatchImmediately.

Modified Paths

Diff

Modified: trunk/Source/WebKit2/ChangeLog (161017 => 161018)


--- trunk/Source/WebKit2/ChangeLog	2013-12-23 22:01:12 UTC (rev 161017)
+++ trunk/Source/WebKit2/ChangeLog	2013-12-23 22:05:22 UTC (rev 161018)
@@ -1,3 +1,12 @@
+2013-12-23  Zan Dobersek  <zdober...@igalia.com>
+
+        Unreviewed build fix for GTK and EFL after r161007.
+
+        * UIProcess/DrawingAreaProxyImpl.cpp:
+        (WebKit::DrawingAreaProxyImpl::waitForAndDispatchDidUpdateBackingStoreState):
+        Use std::chrono::milliseconds instead of double for the timeout parameter to
+        CoreIPC::Connection::waitForAndDispatchImmediately.
+
 2013-12-23  Gustavo Noronha Silva  <g...@gnome.org>
 
         [GTK] [CMake] Add support for generating gtkdoc

Modified: trunk/Source/WebKit2/UIProcess/DrawingAreaProxyImpl.cpp (161017 => 161018)


--- trunk/Source/WebKit2/UIProcess/DrawingAreaProxyImpl.cpp	2013-12-23 22:01:12 UTC (rev 161017)
+++ trunk/Source/WebKit2/UIProcess/DrawingAreaProxyImpl.cpp	2013-12-23 22:05:22 UTC (rev 161018)
@@ -308,9 +308,8 @@
     // message, if multiple DidUpdateBackingStoreState messages are waiting to be processed. For instance, we could
     // choose the most recent one, or the one that is closest to our current size.
 
-    // The timeout, in seconds, we use when waiting for a DidUpdateBackingStoreState message when we're asked to paint.
-    static const double didUpdateBackingStoreStateTimeout = 0.5;
-    m_webPageProxy->process().connection()->waitForAndDispatchImmediately<Messages::DrawingAreaProxy::DidUpdateBackingStoreState>(m_webPageProxy->pageID(), didUpdateBackingStoreStateTimeout);
+    // The timeout we use when waiting for a DidUpdateBackingStoreState message when we're asked to paint is 500 milliseconds.
+    m_webPageProxy->process().connection()->waitForAndDispatchImmediately<Messages::DrawingAreaProxy::DidUpdateBackingStoreState>(m_webPageProxy->pageID(), std::chrono::milliseconds(500));
 #endif
 }
 
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to